@@ -10,6 +10,7 @@
 #' converting to live access database.
 #'
 #' @name backend-impala
+#' @aliases NULL
 #' @examples
 #' library(dplyr, warn.conflicts = FALSE)
 #'
@@ -18,7 +19,7 @@
 NULL
 
 #' @export
-#' @rdname simulate_dbi
+#' @rdname backend-impala
 simulate_impala <- function() simulate_dbi("Impala")
 
 #' @export
@@ -49,5 +50,5 @@ sql_translation.Impala <- function(con) {
 sql_table_analyze.Impala <- function(con, table, ...) {
   # Using COMPUTE STATS instead of ANALYZE as recommended in this article
   # https://www.cloudera.com/documentation/enterprise/5-9-x/topics/impala_compute_stats.html
-  build_sql("COMPUTE STATS ", as.sql(table, con = con), con = con)
+  glue_sql2(con, "COMPUTE STATS {.tbl table}")
 }
