@@ -37,11 +37,14 @@ test_that("custom aggregates translated", {
 
   expect_equal(test_translate_sql(median(x, na.rm = TRUE), window = FALSE), sql('MEDIAN(`x`)'))
   expect_equal(test_translate_sql(sd(x, na.rm = TRUE), window = FALSE), sql('STDEV(`x`)'))
-
-  expect_snapshot({
-    (expect_error(test_translate_sql(quantile(x, 0.5, na.rm = TRUE), window = FALSE)))
-    (expect_error(test_translate_sql(quantile(x, 0.5, na.rm = TRUE), window = TRUE)))
-  })
+  expect_error(
+    test_translate_sql(quantile(x, 0.5, na.rm = TRUE), window = FALSE),
+    class = "dbplyr_error_unsupported_fn"
+  )
+  expect_error(
+    test_translate_sql(quantile(x, 0.5, na.rm = TRUE), window = TRUE),
+    class = "dbplyr_error_unsupported_fn"
+  )
 })
 
 test_that("custom SQL translation", {
